@@ -7,7 +7,7 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
         fixed = "list", clp0 = "list", makeps = "character", 
         clpequspec = "list", lclp0 = "logical", lclpequ = "logical", 
         title = "character", mhist = "list", datCall = "list", 
-        dscalspec = "list", mvecind = "vector", 
+        dscalspec = "list", mvecind = "vector", dscal = "list",
         drel = "vector", clpequ = "vector", scalx = "numeric", 
         prel = "vector", prelspec = "list", fvecind = "vector", 
         pvecind = "vector", nvecind = "vector",
@@ -19,7 +19,8 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	clpType = "character", clpequspecBD = "list", compnames = "vector", 
 	getXsuper = "logical", usecompnames0 = "logical", 
 	usecompnamesequ = "logical", autoclp0 = "list", cohcol = "numeric",
-        weightList = "list", outMat = "matrix", satMat = "matrix"), 
+        weightList = "list", outMat = "matrix", satMat = "matrix", 
+	lscalpar = "logical", thetascal = "vector"), 
         prototype = list(psi.df = matrix(), psi.weight = matrix(), 
             x = vector(), nt = integer(), x2 = vector(), nl = integer(), 
             C2 = matrix(), E2 = matrix(), sigma = numeric(), 
@@ -29,8 +30,7 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
             clpequspec = list(), clpCon = list(), lclp0 = logical(), 
             lclpequ = logical(), makeps = character(), title = character(), 
             mhist = list(), datCall = list(), nvecind = vector(), 
-            #dscal = list(),
-	    drel = vector(),  mvecind = vector(),
+            dscal = list(), drel = vector(),  mvecind = vector(),
             scalx = 1, prel = vector(), prelspec = list(), fvecind = vector(), 
             pvecind = vector(), clpequ = vector(), free = list(),
             iter = 1, ncomp = numeric(), clpdep = logical(),inten = matrix(), 
@@ -40,7 +40,8 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	    clpType = "", clpequspecBD = list(), compnames = vector(),
 	    getXsuper = FALSE, usecompnames0 = FALSE,  
 	    usecompnamesequ = FALSE, autoclp0 = list(), cohcol = 0,
-            weightList = list(), outMat = matrix(), satMat = matrix() ))
+            weightList = list(), outMat = matrix(), satMat = matrix(), 
+	    lscalpar = FALSE, thetascal = vector() ))
 
 setClass("kin", representation("dat", kinpar = "vector", specpar =
 "list", seqmod = "logical", irf = "logical", mirf = "logical", reftau
@@ -66,8 +67,7 @@ TRUE, irf = FALSE, mirf = FALSE, measured_irf = vector(), convalg = 1,
 cohirf = vector(), irffun = "gaus", anispec = list(), irfpar =
 vector(), dispmu = FALSE, dispmufun = "poly", parmu = list(), anipar =
 vector(), disptaufun = "poly", reftau = 0, specpar = list(), 
-partau = vector(), #posk = FALSE,
-disptau = FALSE, fullk = FALSE,
+partau = vector(), disptau = FALSE, fullk = FALSE,
 kmat = array(), jvec = vector(), 
 ncolc = vector(), kinscal = vector(), kmatfit = array(), 
 cohspec = list(), coh = vector(), oscspec = list(), oscpar = vector(), wavedep = logical(), 
